==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/ItemLegendDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { LegendBaseDescriptionMetadata } from "./LegendBaseDescriptionMetadata";
import { ItemLegendDescription } from "./ItemLegendDescription";
/**
 * @hidden
 */
export let ItemLegendDescriptionMetadata = /*@__PURE__*/ (() => {
    class ItemLegendDescriptionMetadata extends Base {
        static e(a) {
            a.item("Width", "(w:Width/DimensionTransform,xam:Width/DimensionTransform)String");
            a.item("Height", "(w:Height/DimensionTransform,xam:Height/DimensionTransform)String");
        }
        static b(a) {
            if (ItemLegendDescriptionMetadata.a == null) {
                ItemLegendDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ItemLegendDescriptionMetadata.c(ItemLegendDescriptionMetadata.a);
            }
            if (a.k(ItemLegendDescriptionMetadata.a)) {
                return;
            }
            a.aa(ItemLegendDescriptionMetadata.a);
        }
        static c(a) {
            LegendBaseDescriptionMetadata.c(a);
            a.item("Orientation", "ExportedType:string:LegendOrientation");
            a.item("Orientation@names", "Horizontal;Vertical");
            a.item("TextColor", "String");
            a.item("TextStyle", "String");
            ItemLegendDescriptionMetadata.e(a);
        }
        static d(a) {
            ItemLegendDescriptionMetadata.b(a);
            a.ac("ItemLegend", () => new ItemLegendDescription());
            a.ab("ItemLegend", ItemLegendDescriptionMetadata.a);
        }
    }
    ItemLegendDescriptionMetadata.$t = /*@__PURE__*/ markType(ItemLegendDescriptionMetadata, 'ItemLegendDescriptionMetadata');
    ItemLegendDescriptionMetadata.a = null;
    return ItemLegendDescriptionMetadata;
})();

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm2015/lib/ItemLegendDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { LegendBaseDescriptionMetadata } from "./LegendBaseDescriptionMetadata";
import { ItemLegendDescription } from "./ItemLegendDescription";
/**
 * @hidden
 */
export let ItemLegendDescriptionMetadata = /*@__PURE__*/ (() => {
    class ItemLegendDescriptionMetadata extends Base {
        static e(a) {
            a.item("_qualifiedName", "String:Infragistics.Controls.Charts.ItemLegend");
            a.item("Width", "(w:Width/DimensionTransform,xam:Width/DimensionTransform)String");
            a.item("Height", "(w:Height/DimensionTransform,xam:Height/DimensionTransform)String");
        }
        static b(a) {
            if (ItemLegendDescriptionMetadata.a == null) {
                ItemLegendDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ItemLegendDescriptionMetadata.c(ItemLegendDescriptionMetadata.a);
            }
            if (a.k(ItemLegendDescriptionMetadata.a)) {
                return;
            }
            a.ac(ItemLegendDescriptionMetadata.a);
        }
        static c(a) {
            LegendBaseDescriptionMetadata.c(a);
            a.item("Orientation", "ExportedType:string:LegendOrientation");
            a.item("Orientation@names", "Horizontal;Vertical");
            a.item("TextColor", "String");
            a.item("TextStyle", "String");
            ItemLegendDescriptionMetadata.e(a);
        }
        static d(a) {
            ItemLegendDescriptionMetadata.b(a);
            a.ae("ItemLegend", () => new ItemLegendDescription());
            a.ad("ItemLegend", ItemLegendDescriptionMetadata.a);
        }
    }
    ItemLegendDescriptionMetadata.$t = /*@__PURE__*/ markType(ItemLegendDescriptionMetadata, 'ItemLegendDescriptionMetadata');
    ItemLegendDescriptionMetadata.a = null;
    return ItemLegendDescriptionMetadata;
})();
